# ImageCrawler: Pr0gramm

## Purpose

A Crawler for [https://pr0gramm.com](https://pr0gramm.com)


## Config

### `promoted`

- Search only top("beliebt") voted content? Otherwise search anything("neu").
- type: boolean
- default: True
- example: False

### `tags`

- None, or a string that starts with "!" - see the German [docs](https://pr0gramm.com/new/2782197).
- type: None or string
- default: None
- example: '!s:500 kadse -text'
